/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * Face.cpp
 *
 *  Created on: Aug 18, 2009
 *      Author: jwienke
 */

#include "Face.h"
#include "PerceptList.h"

using namespace std;
using namespace xmltio;
using namespace airobots;

namespace airobots {

Face::Face() :
	angle(0), angleVariance(0), height(0), heightVariance(0), distance(0),
			distanceVariance(0), reliability(0), faceWidthAngle(0),
			lineOfSight(0), imagePositionX(0), imagePositionY(0),
			imageWidth(0), imageHeight(0) {

}

Face::~Face() {
}

std::string Face::getBaseTag() {
	return "FACE";
}

std::string Face::getTemplate() {
	return string("<") + getBaseTag() + ">" + "<GENERATOR/>"
			+ Timestamp::getTemplate()
			+ "<POSITION angle=\"\" angleVariance=\"\" height=\"\" heightVariance=\"\" distance=\"\" distanceVariance=\"\" />"
			+ "<IMAGEPOSITION x=\"\" y=\"\" width=\"\" height=\"\" />"
			+ "<DATA lineOfSight=\"\" faceWidthAngle=\"\" reliability=\"\"/>"
			+ "</" + getBaseTag() + ">";
}

std::string Face::getPerceptName() {
	return "face";
}

float Face::getAngle() const {
	return this->angle;
}

void Face::setAngle(float angle) {
	this->angle = angle;
}

float Face::getHeight() const {
	return this->height;
}

void Face::setHeight(float height) {
	this->height = height;
}

float Face::getDistance() const {
	return this->distance;
}

void Face::setDistance(float distance) {
	this->distance = distance;
}

float Face::getAngleVariance() const {
	return angleVariance;
}

void Face::setAngleVariance(float angleVariance) {
	this->angleVariance = angleVariance;
}

float Face::getHeightVariance() const {
	return heightVariance;
}

void Face::setHeightVariance(float heightVariance) {
	this->heightVariance = heightVariance;
}

float Face::getDistanceVariance() const {
	return distanceVariance;
}

void Face::setDistanceVariance(float distanceVariance) {
	this->distanceVariance = distanceVariance;
}

float Face::getReliability() const {
	return reliability;
}

void Face::setReliability(float reliability) {
	this->reliability = reliability;
}

float Face::getFaceWidthAngle() const {
	return faceWidthAngle;
}

void Face::setFaceWidthAngle(float faceWidthAngle) {
	this->faceWidthAngle = faceWidthAngle;
}

int Face::getLineOfSight() const {
	return lineOfSight;
}

void Face::setLineOfSight(int lineOfSight) {
	this->lineOfSight = lineOfSight;
}

unsigned int Face::getImagePositionX() const
{
	return imagePositionX;
}

void Face::setImagePositionX(unsigned int x)
{
	this->imagePositionX = x;
}

unsigned int Face::getImagePositionY() const
{
	return imagePositionY;
}

void Face::setImagePositionY(unsigned int y)
{
	this->imagePositionY = y;
}

unsigned int Face::getImageWidth() const
{
	return imageWidth;
}

void Face::setImageWidth(unsigned int imageWidth)
{
	this->imageWidth = imageWidth;
}

unsigned int Face::getImageHeight() const
{
	return imageHeight;
}

void Face::setImageHeight(unsigned int imageHeight)
{
	this->imageHeight = imageHeight;
}

bool Face::operator==(const Face &other) const {

	return Type::operator==(other) && (other.angle == angle) && (other.distance
			== distance) && (other.height == height) && (other.angleVariance
			== angleVariance) && (other.distanceVariance == distanceVariance)
			&& (other.heightVariance == heightVariance) && (other.reliability
			== reliability) && (other.faceWidthAngle == faceWidthAngle)
			&& (other.lineOfSight == lineOfSight) && (other.imagePositionX
			== imagePositionX) && (other.imagePositionY == imagePositionY)
			&& (other.imageWidth == imageWidth) && (other.imageHeight
			== imageHeight);

}

std::ostream& operator<<(std::ostream& o, Face const& face) {

	return o << "Face [angle = " << face.getHeight() << ", angleVariance = "
			<< face.getAngleVariance() << ", distance = " << face.getDistance()
			<< ", distanceVariance = " << face.getDistanceVariance()
			<< ", height = " << face.getHeight() << ", heightVariance = "
			<< face.getHeightVariance() << ", lineOfSight = "
			<< face.getLineOfSight() << ", faceWidthAngle = "
			<< face.getFaceWidthAngle() << ", reliability = "
			<< face.getReliability() << ", imagePositionX = "
			<< face.getImagePositionX() << ", imagePositionY = "
			<< face.getImagePositionY() << ", imageWdith = "
			<< face.getImageWidth() << ", imageHeight = "
			<< face.getImageHeight() << "]";

}

void Face::sanitizeLocation(xmltio::Location &loc) const {
	
}

void Face::fillInto(xmltio::Location &loc) const {

	Type::fillInto(loc);

	loc[XPath("POSITION/@angle")] = getAngle();
	loc[XPath("POSITION/@angleVariance")] = getAngleVariance();
	loc[XPath("POSITION/@height")] = getHeight();
	loc[XPath("POSITION/@heightVariance")] = getHeightVariance();
	loc[XPath("POSITION/@distance")] = getDistance();
	loc[XPath("POSITION/@distanceVariance")] = getDistanceVariance();

	loc[XPath("IMAGEPOSITION/@x")] = getImagePositionX();
	loc[XPath("IMAGEPOSITION/@y")] = getImagePositionY();
	loc[XPath("IMAGEPOSITION/@width")] = getImageWidth();
	loc[XPath("IMAGEPOSITION/@height")] = getImageHeight();


	loc[XPath("DATA/@lineOfSight")] = getLineOfSight();
	loc[XPath("DATA/@faceWidthAngle")] = getFaceWidthAngle();
	loc[XPath("DATA/@reliability")] = getReliability();

}

void Face::fromLocation(const xmltio::Location &loc_, Face &face) {

	Type::fromLocation(loc_, face);

	face.setAngle(extract<float> (loc_[XPath("POSITION/@angle")]));
	face.setAngleVariance(extract<float> (
			loc_[XPath("POSITION/@angleVariance")]));
	face.setHeight(extract<float> (loc_[XPath("POSITION/@height")]));
	face.setHeightVariance(extract<float> (loc_[XPath(
			"POSITION/@heightVariance")]));
	face.setDistance(extract<float> (loc_[XPath("POSITION/@distance")]));
	face.setDistanceVariance(extract<float> (loc_[XPath(
			"POSITION/@distanceVariance")]));

	face.setImagePositionX(extract<unsigned int> (
			loc_[XPath("IMAGEPOSITION/@x")]));
	face.setImagePositionY(extract<unsigned int> (
			loc_[XPath("IMAGEPOSITION/@y")]));
	face.setImageWidth(extract<unsigned int> (
			loc_[XPath("IMAGEPOSITION/@width")]));
	face.setImageHeight(extract<unsigned int> (loc_[XPath(
			"IMAGEPOSITION/@height")]));

	face.setLineOfSight(extract<int> (loc_[XPath("DATA/@lineOfSight")]));
	face.setFaceWidthAngle(extract<float> (loc_[XPath("DATA/@faceWidthAngle")]));
	face.setReliability(extract<float> (loc_[XPath("DATA/@reliability")]));

}

}
