/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

/*
 * ImageData.cpp
 *
 *  Created on: Sep 21, 2010
 *      Author: maschroe
 */

#include "ImageData.h"

using namespace xmltio;
using namespace airobots;

ImageData::ImageData()
	: Type() {
}

ImageData::~ImageData() {
}

std::string airobots::ImageData::getBaseTag() {
	return "IMAGESET";
}

std::string airobots::ImageData::getTemplate() {
	return 	"<" + getBaseTag() + ">"
				+ "<GENERATOR/>"
				+ "<IMAGE uri=\"\">"
				+ airobots::Timestamp::getTemplate()
				+ "<PROPERTIES colorspace=\"\" height=\"\" subsampling=\"\" width=\"\"/>"
				+ "</" + getBaseTag() + ">";
}

void airobots::ImageData::sanitizeLocation(xmltio::Location & loc) const {
}

void airobots::ImageData::fillInto(xmltio::Location & loc) const {

	Type::fillInto(loc);

	loc[XPath("IMAGE/@uri")] = getUri();
	loc[XPath("IMAGE/PROPERTIES/@width")] = getWidth();
	loc[XPath("IMAGE/PROPERTIES/@height")] = getHeight();
	loc[XPath("IMAGE/PROPERTIES/@colorspace")] = getColorspace();
}

void airobots::ImageData::fromLocation(const xmltio::Location & loc, ImageData & type) {

	Type::fromLocation(loc, type);

	type.setUri(extract<std::string>(loc[XPath("IMAGE/@uri")]));
	type.setWidth(extract<int>(loc[XPath("IMAGE/PROPERTIES/@width")]));
	type.setHeight(extract<int>(loc[XPath("IMAGE/PROPERTIES/@height")]));
	type.setColorspace(extract<std::string>(loc[XPath("IMAGE/PROPERTIES/@colorspace")]));
}

std::string ImageData::getColorspace() const {
    return colorspace;
}

int ImageData::getHeight() const {
    return height;
}

std::string ImageData::getUri() const {
    return uri;
}

int ImageData::getWidth() const {
    return width;
}

void ImageData::setColorspace(std::string colorspace) {
    this->colorspace = colorspace;
}

void ImageData::setHeight(int height) {
    this->height = height;
}

void ImageData::setUri(std::string uri) {
    this->uri = uri;
}

void ImageData::setWidth(int width) {
    this->width = width;
}

