/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#ifndef OBJECTPOSITIONDATA_H_
#define OBJECTPOSITIONDATA_H_

#include <string>
#include <vector>
#include <list>

#include <xmltio/xmltio.hpp>

#include "Type.h"
#include "ObjectData.h"

namespace airobots {

/**
 * Results of the object recognition.
 *
 * @author lziegler
 */
class ObjectPositionData: public ObjectData {

public:
	enum Unit {
		MILLIMETER, CENTIMETER, METER
	};

	class Hypothesis: public ObjectData::Hypothesis {
	private:
		std::vector<std::pair<double, double> > polygon;
		std::string reference;
		std::string coordinateKind;
		std::vector<std::pair<double, double> > scalePolygon(std::vector<
				std::pair<double, double> > poly, double factor) const;

	public:

		static std::string getBaseTag();
		static std::string getTemplate();

		Hypothesis();
		Hypothesis(std::string generator);

		std::vector<std::pair<double, double> > getPolygon(Unit unit) const;
		void setPolygon(const std::vector<std::pair<double, double> > &polygon,
				Unit unit);

		std::string getCoordinateKind() const;
		void setCoordinateKind(const std::string &kind);

		std::string getReference() const;
		void setReference(const std::string &ref);

		virtual bool operator==(const Hypothesis &other) const;

		void sanitizeLocation(xmltio::Location&) const;
		void fillInto(xmltio::Location &loc) const;
		static void fromLocation(const xmltio::Location &loc, Hypothesis &type);

	};

	static std::string getBaseTag();

	static std::string getTemplate();

	ObjectPositionData();
	ObjectPositionData(std::string generator);

	std::vector<Hypothesis> getPositionHypotheses() const;
	void addHypothesis(Hypothesis &h);

	virtual bool operator==(const ObjectPositionData &other) const;

	void sanitizeLocation(xmltio::Location&) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc,
			ObjectPositionData &type);

};

}

#endif /* OBJECTPOSITIONDATA_H_ */
