/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/

#ifndef RATINGLIST_H_
#define RATINGLIST_H_

#include "Type.h"
#include <map>
#include <string>
#include <math.h>

namespace airobots {

class RatingList: public Type {
public:
	struct XcfHashKey {
		std::string key1, key2;
		bool operator<(const XcfHashKey other) const {
			return key1.compare(key2) < 0;
		}
	};

	RatingList();
	virtual ~RatingList();

	static std::string getBaseTag();
	static std::string getTemplate();

	void sanitizeLocation(xmltio::Location & loc) const;
	void fillInto(xmltio::Location &loc) const;
	static void fromLocation(const xmltio::Location &loc, RatingList &type);

	void addRating(std::string key1, std::string key2, double value);
	void addRating(XcfHashKey key, double value);
	void addRatingWOC(XcfHashKey key, double value);

	double getRating(std::string key1, std::string key2);
	std::map<XcfHashKey, double> getRatings();
	int size();
	void clearValues();
	void setTolerance(double tol);
	void setUpdateNeeded(bool needed);
	void removeID(std::string id);
	bool shouldBeUpdated();

private:
	std::map<XcfHashKey, double> values;
	double tolerance;
	bool updateNeeded;
};

}

#endif /* RATINGLIST_H_ */
