/*
* This file is part of Bielefeld Type Library (BTL).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/btl
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Matthias Schröder, Norman Köster,
* 				Lukas Twardon, Torben Töniges, Annika Rothert, Marian Pohling,
* 				Denis Schulze, Viktor Richter, Birte Carlmeyer, Maikel Linke
*/
package de.unibi.airobots.btl.data;

import static org.junit.Assert.*;
import nu.xom.Builder;
import nu.xom.Document;
import nu.xom.Element;

import org.apache.log4j.Logger;
import org.junit.Test;

import de.unibi.airobots.btl.TestUtils;
import de.unibi.airobots.btl.common.Timestamp;

/**
 * Test cases for {@link Type}.
 * 
 * @author jwienke
 */
public class BinarySlamMapTest {

	private Logger logger = Logger.getLogger(getClass());

	@Test
	public void selfCompatibility() throws Exception {

		BinarySlamMap original = new BinarySlamMap();
		final long timestamp = System.currentTimeMillis();
		original.setTimestamp(timestamp);
		original.setGenerator("test");
		original.setHeight(23445);
		original.setOriginX(-345);
		original.setOriginY(123);
		original.setResolution(0.034);
		original.setUri("blubber/bla");
		original.setWidth(34539);
		original.setX(0.45);
		original.setY(-216.34);
		original.setYaw(0.34);

		Document doc = new Document(new Element(BinarySlamMap.getBaseTag()));
		original.fillInto(doc.getRootElement());
		logger.info(doc.toXML());

		BinarySlamMap parsed = new BinarySlamMap();
		BinarySlamMap.fromElement(doc.getRootElement(), parsed);

		assertEquals(original.getGenerator(), parsed.getGenerator());
		assertEquals(original.getTimestamp(), parsed.getTimestamp());
		assertEquals(original.getHeight(), parsed.getHeight());
		assertEquals(original.getOriginX(), parsed.getOriginX());
		assertEquals(original.getOriginY(), parsed.getOriginY());
		assertEquals(original.getResolution(), parsed.getResolution(), 0.00001);
		assertEquals(original.getUri(), parsed.getUri());
		assertEquals(original.getWidth(), parsed.getWidth());
		assertEquals(original.getX(), parsed.getX(), 0.0001);
		assertEquals(original.getY(), parsed.getY(), 0.0001);
		assertEquals(original.getYaw(), parsed.getYaw(), 0.0001);

	}

	@Test
	public void fileCompatibility() throws Exception {

		Builder parser = new Builder();
		Document doc = parser.build(TestUtils
				.makeTestFileName("BinarySlamMap.xml"));

		BinarySlamMap parsed = new BinarySlamMap();
		BinarySlamMap.fromElement(doc.getRootElement(), parsed);
		assertEquals(doc.getRootElement().getLocalName(), BinarySlamMap
				.getBaseTag());

		assertEquals("test", parsed.getGenerator());
		assertEquals(new Timestamp(12345, 67890), parsed.getTimestamp());
		assertEquals(74, parsed.getOriginX());
		assertEquals(34, parsed.getOriginY());
		assertEquals(0.45, parsed.getResolution(), 0.00001);
		assertEquals(745, parsed.getWidth());
		assertEquals(123, parsed.getHeight());
		assertEquals(0.34, parsed.getYaw(), 0.00001);
		assertEquals("test/uri", parsed.getUri());
		assertEquals(234.5, parsed.getX(), 0.00001);
		assertEquals(-6345.42, parsed.getY(), 0.00001);

	}

}
